# AIFrameWork

This is a Python library that provides functionality for performing machine learning tasks with ease. 

## Installation

You can install this library using pip:

```bash
pip install AIFrameWork
```
Usage

Here is an example of how to use this library. 

SINGLE TARGET REGRESSION 

from my_library import RegressionSingleTarget

# Create an instance of the regression model
model = RegressionSingleTarget()

# Fit the model to the training data
model.fit(X_train, y_train)

# Predict on the test data
y_pred = model.predict(X_test)



